@@ -1,7 +1,7 @@
 package Software::Catalog::SW::zotero;
 
-our $DATE = '2018-10-05'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2019-10-26'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -14,22 +14,9 @@ use Role::Tiny::With;
 with 'Versioning::Scheme::Dotted';
 with 'Software::Catalog::Role::Software';
 
-our %SPEC;
+sub homepage_url { "https://www.zotero.org/" }
 
-sub meta {
-    return {
-        homepage_url => "https://www.zotero.org/",
-    };
-}
-
-$SPEC{get_latest_version} = {
-    v => 1.1,
-    is_meth => 1,
-    args => {
-        arch => { schema=>'software::arch*', req=>1 },
-    },
-};
-sub get_latest_version {
+sub latest_version {
     my ($self, %args) = @_;
 
     my $carch = $args{arch};
@@ -52,20 +39,12 @@ sub canon2native_arch_map {
     },
 }
 
-$SPEC{get_latest_version} = {
-    v => 1.1,
-    is_meth => 1,
-    args => {
-        version => { schema=>'software::version*' },
-        arch => { schema=>'software::arch*', req=>1 },
-    },
-};
-sub get_download_url {
+sub download_url {
     my ($self, %args) = @_;
 
     my $version = $args{version};
     if (!$version) {
-        my $verres = $self->get_latest_version(arch => $args{arch});
+        my $verres = $self->latest_version(arch => $args{arch});
         return [500, "Can't get latest version: $verres->[0] - $verres->[1]"]
             unless $verres->[0] == 200;
         $version = $verres->[2];
@@ -82,7 +61,7 @@ sub get_download_url {
      }];
 }
 
-sub get_archive_info {
+sub archive_info {
     my ($self, %args) = @_;
     [200, "OK", {
         programs => [
@@ -106,42 +85,10 @@ Software::Catalog::SW::zotero - Zotero
 
 =head1 VERSION
 
-This document describes version 0.004 of Software::Catalog::SW::zotero (from Perl distribution Software-Catalog-SW-zotero), released on 2018-10-05.
+This document describes version 0.005 of Software::Catalog::SW::zotero (from Perl distribution Software-Catalog-SW-zotero), released on 2019-10-26.
 
 =for Pod::Coverage ^(.+)$
 
-=head1 FUNCTIONS
-
-
-=head2 get_latest_version
-
-Usage:
-
- get_latest_version(%args) -> [status, msg, result, meta]
-
-This function is not exported.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<arch>* => I<software::arch>
-
-=item * B<version> => I<software::version>
-
-=back
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-Return value:  (any)
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Software-Catalog-SW-zotero>.
@@ -164,7 +111,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
